0.1.0 [May 14th, 2021]:
---
 * Release of first stable version, to use in multiples pipelines

0.1.0a1 [Apr 22nd, 2021]:
---
 * Encode/Decode the types, plus identifier logic
 * First release of the package, in alpha status
